Index: /trunk/MagicSoft/Mars/mmontecarlo/MMcCollectionAreaCalc.cc
===================================================================
--- /trunk/MagicSoft/Mars/mmontecarlo/MMcCollectionAreaCalc.cc	(revision 1612)
+++ /trunk/MagicSoft/Mars/mmontecarlo/MMcCollectionAreaCalc.cc	(revision 1613)
@@ -95,10 +95,10 @@
 
     if (fTheta>=0 && fTheta!=runheader->GetTelesTheta())
-        *fLog << warn << dbginf << "Warning - Read files have different TelesTheta... exit." << endl;
+        *fLog << warn << dbginf << "Warning - Read files have different TelesTheta..." << endl;
 
     fTheta = runheader->GetTelesTheta();
 
     if (fCorsikaVersion!=0 && fCorsikaVersion!=runheader->GetCorsikaVersion())
-        *fLog << warn << dbginf << "Warning - Read files have different Corsika versions... exit." << endl;
+        *fLog << warn << dbginf << "Warning - Read files have different Corsika versions..." << endl;
 
     fCorsikaVersion = runheader->GetCorsikaVersion();

Index: /trunk/MagicSoft/Mars/mhist/MHMcCollectionArea.cc
===================================================================
--- /trunk/MagicSoft/Mars/mhist/MHMcCollectionArea.cc	(revision 1612)
+++ /trunk/MagicSoft/Mars/mhist/MHMcCollectionArea.cc	(revision 1613)
@@ -36,4 +36,5 @@
 
 #include "MH.h"
+#include "MBinning.h"
 #include "MHMcEfficiency.h"
 #include "MHMcEnergyImpact.h"
@@ -52,36 +53,31 @@
     //   initialize the histogram for the distribution r vs E
     //
     //   we set the energy range from 1 Gev to 10000 GeV (in log 5 orders
     //   of magnitude) and for each order we take 10 subdivision --> 50 xbins
     //
     //   we set the radius range from 0 m to 500 m with 10 m bin --> 50 ybins
-
-  
+    //
     fName  = name  ? name  : "MHMcCollectionArea";
     fTitle = title ? title : "Collection Area vs. Energy";
 
-    const Int_t  nbins = 50;
-    const Float_t maxx = 5;
-    const Float_t maxy = 500;
-
-    Float_t *binsx = new Float_t[nbins+1];
-    for (int i=0; i<nbins+1; i++)
-        binsx[i] = pow(10, maxx*i/nbins);
-
-    Float_t *binsy = new Float_t[nbins+1];
-    for (int i=0; i<nbins+1; i++)
-        binsy[i] = maxy*i/nbins;
-
-    fHistAll = new TH2D("AllEvents", "All showers - Radius vs Energy distribution",
-                        nbins, binsx, nbins, binsy);
-    fHistSel = new TH2D("SelectedEvents", "Selected showers - Radius vs Energy distribution",
-                        nbins, binsx, nbins, binsy);
-
-    delete binsx;
-    delete binsy;
-
+    MBinning binsx;
+    MBinning binsy;
+    binsx.SetEdgesLog(50, 10, 20000);
+    binsy.SetEdges   (50,  0,   500);
+
+    fHistAll = new TH2D;
+    fHistSel = new TH2D;
     fHistCol = new TH1D;
+ 
+    MH::SetBinning(fHistAll, &binsx, &binsy);
+    MH::SetBinning(fHistSel, &binsx, &binsy);
+
     fHistCol->SetName(fName);
+    fHistAll->SetName("AllEvents");
+    fHistSel->SetName("SelectedEvents");
+
     fHistCol->SetTitle(fTitle);
+    fHistAll->SetTitle("All showers - Radius vs Energy distribution");
+    fHistSel->SetTitle("Selected showers - Radius vs Energy distribution");
 
     fHistAll->SetDirectory(NULL);
@@ -52,36 +53,31 @@
     //   initialize the histogram for the distribution r vs E
     //
-    //   we set the energy range from 1 Gev to 10000 GeV (in log 5 orders
+    //   we set the energy range from 10 Gev to 20000 GeV (in log 5 orders
     //   of magnitude) and for each order we take 10 subdivision --> 50 xbins
     //